configlet create


Amikor új megközelítést, cikket vagy feladatot adsz hozzá, nagyon meghatározott nevű fájlokat kell létrehoznod. Emellett konfigurációs fájlokat is hozzá kell adni vagy frissíteni. A create paranccsal a configlet mindezt megteszi helyetted.

Használat

A create paranccsal létrehozhatod az új megközelítés, cikk vagy feladat hozzáadásához szükséges fájlokat, és a konfigurációs fájlokat is módosíthatod vele.

configlet [global-options] create [command-options]

Options for create:
      --approach <slug>           The slug of the approach
      --article <slug>            The slug of the article
      --practice-exercise <slug>  The slug of the practice exercise
      --concept-exercise <slug>   The slug of the concept exercise
  -e, --exercise <slug>           Only operate on this exercise
  -o, --offline                   Do not update the cached 'problem-specifications' data

Gyakorlófeladat létrehozása

A gyakorlófeladat hozzáadásáról szóló dokumentáció részletes útmutatást ad arról, hogyan adj hozzá gyakorlófeladatot.

Tanulófeladat létrehozása

Tanulófeladat létrehozásához meg kell adnod a slugját:

configlet create --concept-exercise bird-watcher

Ezzel létrejönnek a tanulófeladat szükséges fájljai, ahogy a tanulófeladatokról szóló dokumentáció leírja.

Ez persze csak az első lépés egy feladat létrehozása felé. Ezután a következőket kell megtenned:

  • Tegyél teszteket a tesztfájlba
  • Adj hozzá egy mintamegoldást
  • Határozd meg a stub fájl tartalmát
  • Írd meg a bevezetőt a .docs/introduction.md fájlban
  • Írd meg az utasításokat a .docs/instructions.md fájlban
  • A feladat .meta/config.json fájljában:
    • Add hozzá a feladat szerzőinek GitHub-felhasználónevét az authors kulcshoz
  • A kurzus config.json fájljában:
    • Ellenőrizd, illetve frissítsd a feladat nehézségét
    • Adj hozzá fogalmakat a concepts kulcshoz
    • Adj hozzá fogalmakat a prerequisites kulcshoz

Megközelítés létrehozása

Egy megközelítés fájljainak létrehozásához meg kell adnod a megközelítés és a hozzá tartozó feladat slugját:

configlet create --approach recursion --exercise collatz-conjecture

Ezzel létrejönnek a megközelítés szükséges fájljai, ahogy a megközelítésekről szóló dokumentáció leírja.

Cikk létrehozása

Egy cikk fájljainak létrehozásához meg kell adnod a cikk és a hozzá tartozó feladat slugját:

configlet create --article performance --exercise collatz-conjecture

Ezzel létrejönnek a cikk szükséges fájljai, ahogy a cikkekről szóló dokumentáció leírja.